
# popcat-py

Doru's popcat clicker.

Clicks like crazy.

Go Romania!

# How to use
Download this [geckodriver](https://github.com/mozilla/geckodriver/releases) for your OS

Extract and add the executable to your PATH env variable.

Run `popcat`
